@@ -29,7 +29,7 @@ class RequestQueueLengthMetric(CalculatedMetric):
 
     code = "request_queue_length"
 
-    def get_value(cls):
+    def get_value(self):
 
         """
         Getting length of the asyncio queue of all tasks.
@@ -40,3 +40,11 @@ class RequestQueueLengthMetric(CalculatedMetric):
 
 class StartupTimeMetric(StoredMetric):
     code = "startup_time"
+
+
+class HealthMetric(StoredMetric):
+    code = "health"
+
+
+class ReadinessMetric(StoredMetric):
+    code = "readiness"
